@@ -159,6 +159,154 @@ bool DataBase::isTheDBCreated()
     }
     return false;
 }
+
+bool DataBase::createTableLog()
+{ //Creates log=0 or selectedlog=1
+
+    //QString logToCreate = "log";
+
+    QSqlQuery query;
+
+    QString stringQuery = "CREATE TABLE log" ;
+
+
+             stringQuery = stringQuery + QString(" (id INTEGER PRIMARY KEY AUTOINCREMENT, "
+             "qso_date VARCHAR(10) NOT NULL, "
+             "time_on VARCHAR(8) NOT NULL, "
+             "call VARCHAR(40) NOT NULL, "
+             "rst_sent VARCHAR, "
+             "rst_rcvd VARCHAR, "
+             "bandid INTEGER NOT NULL, "
+             "modeid INTEGER NOT NULL, "
+             "srx VARCHAR(10), "
+             "stx VARCHAR(10), "
+             "points INTEGER,"
+             "multiplier INTEGER,"
+             "cqz INTEGER,"
+             "ituz INTEGER,"
+             "dxcc INTEGER,"
+             "address VARCHAR, "
+             "age INTEGER, "
+             "cnty VARCHAR, "
+             "comment VARCHAR, "
+             "a_index INTEGER, "
+             "ant_az INTEGER, "
+             "ant_el INTEGER, "
+             "ant_path INTEGER, "
+             "arrl_sect INTEGER, "
+             "band_rx INTEGER, "
+             "checkcontest VARCHAR, "
+             "class VARCHAR, "
+             "contacted_op VARCHAR(40), "
+             "contest_id VARCHAR, "
+             "country VARCHAR, "
+             "credit_submitted VARCHAR, "
+             "credit_granted VARCHAR, "
+             "distance INTEGER, "
+             "email VARCHAR, "
+             "eq_call VARCHAR, "
+             "eqsl_qslrdate VARCHAR(10), "
+             "eqsl_qslsdate VARCHAR(10), "
+             "eqsl_qsl_rcvd VARCHAR(1), "
+             "eqsl_qsl_sent VARCHAR(1), "
+             "force_init INTEGER, "
+             "freq INTEGER, "
+             "freq_rx INTEGER, "
+             "gridsquare VARCHAR, "
+             "iota VARCHAR(6), "
+             "iota_island_id VARCHAR, "
+             "k_index INTEGER, "
+             "lat VARCHAR(11), "
+             "lon VARCHAR(11), "
+             "lotw_qslrdate VARCHAR(10), "
+             "lotw_qslsdate VARCHAR(10), "
+             "lotw_qsl_rcvd VARCHAR(1), "
+             "lotw_qsl_sent VARCHAR(1), "
+             "max_bursts INTEGER, "
+             "ms_shower VARCHAR, "
+             "my_city VARCHAR, "
+             "my_cnty VARCHAR, "
+             "my_country INTEGER, "
+             "my_cq_zone INTEGER, "
+             "my_gridsquare VARCHAR, "
+             "my_iota VARCHAR(6), "
+             "my_iota_island_id VARCHAR, "
+             "my_lat VARCHAR(11), "
+             "my_lon VARCHAR(11), "
+             "my_name VARCHAR, "
+             "my_rig VARCHAR, "
+             "my_sig VARCHAR, "
+             "my_sig_info VARCHAR, "
+             "my_state VARCHAR, "
+             "my_street VARCHAR, "
+             "name VARCHAR, "
+             "notes VARCHAR, "
+             "nr_bursts INTEGER, "
+             "nr_pings INTEGER, "
+             "operator VARCHAR, "
+             "owner_callsign VARCHAR, "
+             "pfx VARCHAR, "
+             "precedence VARCHAR, "
+             "prop_mode VARCHAR(8), "
+             "public_key VARCHAR, "
+             "qslmsg VARCHAR, "
+             "qslrdate VARCHAR(10), "
+             "qslsdate VARCHAR(10), "
+             "qsl_rcvd VARCHAR(1), "
+             "qsl_sent VARCHAR(1), "
+             "qsl_rcvd_via VARCHAR(1), "
+             "qsl_sent_via VARCHAR(1), "
+             "qsl_via VARCHAR, "
+             "qso_complete VARCHAR(1), "
+             "qso_random INTEGER, "
+             "qth VARCHAR, "
+             "rx_pwr REAL, "
+             "sat_mode VARCHAR, "
+             "sat_name VARCHAR, "
+             "sfi INTEGER, "
+             "sig VARCHAR, "
+             "sig_info VARCHAR, "
+             "srx_string VARCHAR, "
+             "stx_string VARCHAR, "
+             "state VARCHAR, "
+             "station_callsign VARCHAR, "
+             "swl INTEGER, "
+             "ten_ten INTEGER, "
+             "tx_pwr REAL, "
+             "web VARCHAR, "
+             "qso_date_off VARCHAR(10), "
+             "time_off VARCHAR(8), "
+             "transmiterid VARCHAR, "
+             "marked VARCHAR(1), "
+             "lognumber INTEGER NOT NULL, "
+
+             "UNIQUE (call, qso_date, time_on, bandid, modeid, lognumber), "
+             "FOREIGN KEY (qso_complete) REFERENCES qso_complete_enumeration, "
+             "FOREIGN KEY (qsl_rcvd_via) REFERENCES qsl_via_enumeration, "
+             "FOREIGN KEY (qsl_sent_via) REFERENCES qsl_via_enumeration, "
+             "FOREIGN KEY (qsl_rcvd) REFERENCES qsl_rec_status, "
+             "FOREIGN KEY (qsl_sent) REFERENCES qsl_sent_status, "
+             "FOREIGN KEY (prop_mode) REFERENCES prop_mode_emumeration, "
+             "FOREIGN KEY (my_country) REFERENCES entity, "
+             "FOREIGN KEY (lotw_qsl_rcvd) REFERENCES qsl_rec_status, "
+             "FOREIGN KEY (lotw_qsl_sent) REFERENCES qsl_sent_status, "
+             "FOREIGN KEY (eqsl_qsl_rcvd) REFERENCES qsl_rec_status, "
+             "FOREIGN KEY (eqsl_qsl_sent) REFERENCES qsl_sent_status, "
+             "FOREIGN KEY (credit_submitted) REFERENCES award_enumeration, "
+             "FOREIGN KEY (credit_granted) REFERENCES award_enumeration, "
+             "FOREIGN KEY (country) REFERENCES entity, "
+             "FOREIGN KEY (ant_path) REFERENCES ant_path_enumeration, "
+             "FOREIGN KEY (arrl_sect) REFERENCES arrl_sect_enumeration, "
+             "FOREIGN KEY (band_rx) REFERENCES band, "
+             "FOREIGN KEY (modeid) REFERENCES mode, "
+             "FOREIGN KEY (dxcc) REFERENCES entity, "
+             "FOREIGN KEY (bandid) REFERENCES band)");
+
+    //qDebug() << "DataBase::createTableLog: " << stringQuery  << endl;
+    return query.exec(stringQuery);
+
+}
+
 bool DataBase::createDataBase()
 {
     //qDebug() << "DataBase::createDataBase"  << endl;
@@ -216,138 +364,8 @@ bool DataBase::createDataBase()
                   "UNIQUE (cabrillo, name) )");
 
 
-      query.exec("CREATE TABLE log ("
-               "id INTEGER PRIMARY KEY AUTOINCREMENT, "
-               "qso_date VARCHAR(10) NOT NULL, "
-               "time_on VARCHAR(8) NOT NULL, "
-               "call VARCHAR(40) NOT NULL, "
-               "rst_sent VARCHAR, "
-               "rst_rcvd VARCHAR, "
-               "bandid INTEGER NOT NULL, "
-               "modeid INTEGER NOT NULL, "
-               "srx VARCHAR(10), "
-               "stx VARCHAR(10), "
-               "points INTEGER,"
-               "multiplier INTEGER,"
-               "cqz INTEGER,"
-               "ituz INTEGER,"
-               "dxcc INTEGER,"
-               "address VARCHAR, "
-               "age INTEGER, "
-               "cnty VARCHAR, "
-               "comment VARCHAR, "
-               "a_index INTEGER, "
-               "ant_az INTEGER, "
-               "ant_el INTEGER, "
-               "ant_path INTEGER, "
-               "arrl_sect INTEGER, "
-               "band_rx INTEGER, "
-               "checkcontest VARCHAR, "
-               "class VARCHAR, "
-               "contacted_op VARCHAR(40), "
-               "contest_id VARCHAR, "
-               "country VARCHAR, "
-               "credit_submitted VARCHAR, "
-               "credit_granted VARCHAR, "
-               "distance INTEGER, "
-               "email VARCHAR, "
-               "eq_call VARCHAR, "
-               "eqsl_qslrdate VARCHAR(10), "
-               "eqsl_qslsdate VARCHAR(10), "
-               "eqsl_qsl_rcvd VARCHAR(1), "
-               "eqsl_qsl_sent VARCHAR(1), "
-               "force_init INTEGER, "
-               "freq INTEGER, "
-               "freq_rx INTEGER, "
-               "gridsquare VARCHAR, "
-               "iota VARCHAR(6), "
-               "iota_island_id VARCHAR, "
-               "k_index INTEGER, "
-               "lat VARCHAR(11), "
-               "lon VARCHAR(11), "
-               "lotw_qslrdate VARCHAR(10), "
-               "lotw_qslsdate VARCHAR(10), "
-               "lotw_qsl_rcvd VARCHAR(1), "
-               "lotw_qsl_sent VARCHAR(1), "
-               "max_bursts INTEGER, "
-               "ms_shower VARCHAR, "
-               "my_city VARCHAR, "
-               "my_cnty VARCHAR, "
-               "my_country INTEGER, "
-               "my_cq_zone INTEGER, "
-               "my_gridsquare VARCHAR, "
-               "my_iota VARCHAR(6), "
-               "my_iota_island_id VARCHAR, "
-               "my_lat VARCHAR(11), "
-               "my_lon VARCHAR(11), "
-               "my_name VARCHAR, "
-               "my_rig VARCHAR, "
-               "my_sig VARCHAR, "
-               "my_sig_info VARCHAR, "
-               "my_state VARCHAR, "
-               "my_street VARCHAR, "
-               "name VARCHAR, "
-               "notes VARCHAR, "
-               "nr_bursts INTEGER, "
-               "nr_pings INTEGER, "
-               "operator VARCHAR, "
-               "owner_callsign VARCHAR, "
-               "pfx VARCHAR, "
-               "precedence VARCHAR, "
-               "prop_mode VARCHAR(8), "
-               "public_key VARCHAR, "
-               "qslmsg VARCHAR, "
-               "qslrdate VARCHAR(10), "
-               "qslsdate VARCHAR(10), "
-               "qsl_rcvd VARCHAR(1), "
-               "qsl_sent VARCHAR(1), "
-               "qsl_rcvd_via VARCHAR(1), "
-               "qsl_sent_via VARCHAR(1), "
-               "qsl_via VARCHAR, "
-               "qso_complete VARCHAR(1), "
-               "qso_random INTEGER, "
-               "qth VARCHAR, "
-               "rx_pwr REAL, "
-               "sat_mode VARCHAR, "
-               "sat_name VARCHAR, "
-               "sfi INTEGER, "
-               "sig VARCHAR, "
-               "sig_info VARCHAR, "
-               "srx_string VARCHAR, "
-               "stx_string VARCHAR, "
-               "state VARCHAR, "
-               "station_callsign VARCHAR, "
-               "swl INTEGER, "
-               "ten_ten INTEGER, "
-               "tx_pwr REAL, "
-               "web VARCHAR, "
-               "qso_date_off VARCHAR(10), "
-               "time_off VARCHAR(8), "
-               "transmiterid VARCHAR, "
-               "marked VARCHAR(1), "
-               "lognumber INTEGER NOT NULL, "
+    createTableLog();
 
-               "UNIQUE (call, qso_date, time_on, bandid, modeid), "
-               "FOREIGN KEY (qso_complete) REFERENCES qso_complete_enumeration, "
-               "FOREIGN KEY (qsl_rcvd_via) REFERENCES qsl_via_enumeration, "
-               "FOREIGN KEY (qsl_sent_via) REFERENCES qsl_via_enumeration, "
-               "FOREIGN KEY (qsl_rcvd) REFERENCES qsl_rec_status, "
-               "FOREIGN KEY (qsl_sent) REFERENCES qsl_sent_status, "
-               "FOREIGN KEY (prop_mode) REFERENCES prop_mode_emumeration, "
-               "FOREIGN KEY (my_country) REFERENCES entity, "
-               "FOREIGN KEY (lotw_qsl_rcvd) REFERENCES qsl_rec_status, "
-               "FOREIGN KEY (lotw_qsl_sent) REFERENCES qsl_sent_status, "
-               "FOREIGN KEY (eqsl_qsl_rcvd) REFERENCES qsl_rec_status, "
-               "FOREIGN KEY (eqsl_qsl_sent) REFERENCES qsl_sent_status, "
-               "FOREIGN KEY (credit_submitted) REFERENCES award_enumeration, "
-               "FOREIGN KEY (credit_granted) REFERENCES award_enumeration, "
-               "FOREIGN KEY (country) REFERENCES entity, "
-               "FOREIGN KEY (ant_path) REFERENCES ant_path_enumeration, "
-               "FOREIGN KEY (arrl_sect) REFERENCES arrl_sect_enumeration, "
-               "FOREIGN KEY (band_rx) REFERENCES band, "
-               "FOREIGN KEY (modeid) REFERENCES mode, "
-               "FOREIGN KEY (dxcc) REFERENCES entity, "
-               "FOREIGN KEY (bandid) REFERENCES band)");
 
       //DATE YYYY-MM-DD
       //TIME HHmmss
@@ -381,10 +399,12 @@ bool DataBase::createDataBase()
                  "shortname VARCHAR(3) NOT NULL, "
                  "name VARCHAR(10) NOT NULL)");
 
-      query.exec("CREATE TABLE contest ("
+      createTableContest();
+
+      query.exec("CREATE TABLE contestcategory ("
                  "id INTEGER PRIMARY KEY AUTOINCREMENT, "
                  "shortname VARCHAR(20) NOT NULL, "
-                 "name VARCHAR(40) NOT NULL)");
+                 "name VARCHAR(40) NOT NULL");
 
       query.exec("CREATE TABLE award_enumeration ("
                  "id INTEGER PRIMARY KEY AUTOINCREMENT, "
@@ -485,14 +505,21 @@ confirmed = 1     Set as Confirmed
                  "shortname VARCHAR(8) NOT NULL, "
                  "name VARCHAR(55) NOT NULL)");
 
-      query.exec("CREATE TABLE logs ("
+      createTableLogs();
+
+      /*
+      query.exec("CREATE TABLE sat_modes ("
                  "id INTEGER PRIMARY KEY AUTOINCREMENT, "
-                 "logdate VARCHAR(10), "
-                 "stationcall VARCHAR(15) NOT NULL, "
-                 "comment VARCHAR, "
-                 "logtype VARCHAR )");
+                 "name VARCHAR(15) NOT NULL,"
+                 "uplink INTEGER NOT NULL,"
+                 "downlink INTEGER NOT NULL,"
+                 "FOREIGN KEY (uplink) REFERENCES band, "
+                 "FOREIGN KEY (downlink) REFERENCES band)");
+    //http://en.wikipedia.org/wiki/OSCAR#Mode_designators
+
+      //query.exec("INSERT INTO sat_modes (name, uplink, downlink) VALUES ('H', '15M', '148', '144')");
+
 
-/*
       query.exec("CREATE TABLE sat_modes ("
                  "id INTEGER PRIMARY KEY AUTOINCREMENT, "
                  "shortname VARCHAR(8) NOT NULL, "
@@ -505,9 +532,7 @@ confirmed = 1     Set as Confirmed
                  "uplink INTEGER NOT NULL,"
                  "downlink INTEGER NOT NULL,"
                  "FOREIGN KEY (uplink) REFERENCES band, "
-                 "FOREIGN KEY (downlink) REFERENCES band, "
-                 "FOREIGN KEY (dxcc) REFERENCES entity)");
-
+                 "FOREIGN KEY (downlink) REFERENCES band)");
 */
 /*
       qry.prepare( "INSERT INTO names (id, firstname, lastname) VALUES (:id, :firstname, :lastname)" );
@@ -548,6 +573,7 @@ confirmed = 1     Set as Confirmed
       query.exec("INSERT INTO continent (shortname, name) VALUES ('SA', 'South America')");
       query.exec("INSERT INTO continent (shortname, name) VALUES ('AN', 'Antartica')");
 
+      populateContestData();
 
       //To add a band, just create another line:
       query.exec("INSERT INTO band (name, lower, upper, cabrillo) VALUES ('0', '0', '0', 'Light')");
@@ -662,12 +688,6 @@ query.exec("INSERT INTO ant_path_enumeration (shortname, name) VALUES ('L', 'Lon
 
 query.exec("INSERT INTO arrl_sect_enumeration (shortname, name) VALUES ('AL', 'Alabama')");
 
-query.exec("INSERT INTO contest (shortname, name) VALUES ('CQ-WW-SSB', 'CQ WW DX Contest(SSB)')");
-query.exec("INSERT INTO contest (shortname, name) VALUES ('CQ-WW-CW', 'CQ WW DX Contest(CW)')");
-query.exec("INSERT INTO contest (shortname, name) VALUES ('CQ-WPX-SSB', 'CQ WW WPX Contest (SSB)')");
-query.exec("INSERT INTO contest (shortname, name) VALUES ('CQ-WPX-CW', 'CQ WW CW Contest (CW)')");
-query.exec("INSERT INTO contest (shortname, name) VALUES ('CQ-WW-RTTY', 'CQ/RJ WW RTTY DX Contest')");
-
 
 query.exec("INSERT INTO award_enumeration (name) VALUES ('AJA')");
 query.exec("INSERT INTO award_enumeration (name) VALUES ('CQDX')");
@@ -847,21 +867,59 @@ int DataBase::getBandIdFromFreq(const QString fr)
 {
      //qDebug() << "DataBase::getBandIdFromFreq: " << fr << endl;
     //Freq should be in MHz
-    QString queryString = QString("SELECT id FROM band WHERE lower < '%1' and upper > '%2'").arg(fr).arg(fr);    
-    QSqlQuery query(queryString);
-    query.next();
+     bool sqlOk = false;
+    QString queryString = QString("SELECT id FROM band WHERE lower <= '%1' and upper >= '%2'").arg(fr).arg(fr);
 
-    if (query.isValid())
+    QSqlQuery query(queryString);
+    sqlOk = query.exec();
+    //qDebug() << "DataBase::getBandIdFromFreq: Query: " << query.lastQuery() << endl;
+    if (sqlOk)
     {
-        return (query.value(0)).toInt();
+        //qDebug() << "DataBase::getBandIdFromFreq: Query OK" << endl;
+        query.next();
+
+
+        if (query.isValid())
+        {
+            return (query.value(0)).toInt();
+        }
+        else
+        {
+            return -1;
+        }
     }
     else
     {
-        return -1;
+        //qDebug() << "DataBase::getBandIdFromFreq: Query NOK" << endl;
+       return -1;
     }
+
+
     return -1;
 }
 
+
+bool DataBase::isThisFreqInBand(const QString b, const QString fr)
+{//Freq should be in MHz
+   //qDebug() << "DataBase::isThisFreqInBand: " << b << "/" << fr << endl;
+    int bandNf = getBandIdFromFreq(fr);
+    int bandN = getBandIDFromName2(b);
+    //qDebug() << "DataBase::isThisFreqInBand: (b/f)" << QString::number(bandN) << "/" << QString::number(bandNf) << endl;
+    if (bandNf == bandN)
+    {
+        //qDebug() << "DataBase::isThisFreqInBand: OK " << b << "/" << fr << endl;
+        return true;
+    }
+    else
+    {
+        //qDebug() << "DataBase::isThisFreqInBand: NOK " << b << "/" << fr << endl;
+        return false;
+    }
+
+    return false;
+}
+
+
 bool DataBase::unMarkAllQSO()
 {
     QString stringQuery = QString("UPDATE log SET marked = 'N' WHERE 1");
@@ -923,8 +981,8 @@ bool DataBase::updateIfNeeded()
     { // DB is outdated. We need to update!!
 
         QMessageBox msgBox;
-        msgBox.setText("KLog DB needs to be upgraded.");
-        msgBox.setInformativeText("Do you want to upgrade it now?\nIf DB is not upgraded KLog may not work properly.");
+        msgBox.setText( QObject::tr("KLog DB needs to be upgraded."));
+        msgBox.setInformativeText( QObject::tr("Do you want to upgrade it now?\nIf DB is not upgraded KLog may not work properly."));
         msgBox.setStandardButtons(QMessageBox::Apply | QMessageBox::Discard);
         msgBox.setDefaultButton(QMessageBox::Apply);
 
@@ -963,12 +1021,14 @@ bool DataBase::createTheBandQuickReference()
     QHash<QString, int> modeIDHash;
     QHash<int, QString> IDBandHash;
     QHash<int, QString> IDModeHash
+    QHash<double, int> freqBandIdHash;
 
 */
     //qDebug() << "DataBase::createTheBandQuickReference: " << endl;
     QString st = "NULL";
     int in = 0;
-    QSqlQuery query("SELECT id, name FROM band");
+    double fr = 0;
+    QSqlQuery query("SELECT id, name, lower FROM band");
     while (query.next())
     {
 
@@ -976,8 +1036,11 @@ bool DataBase::createTheBandQuickReference()
         {
             st = (query.value(1)).toString();
             in = (query.value(0)).toInt();
+            fr = (query.value(2)).toDouble();
             bandIDHash.insert(st, in );
             IDBandHash.insert(in, st);
+            freqBandIdHash.insert(in, fr);
+
             //qDebug() << "DataBase::createTheBandQuickReference: " << st <<"/" << QString::number(in)<< endl;
         }
         else
@@ -1149,6 +1212,22 @@ bool DataBase::createBandModeMaps()
 
 }
 
+double DataBase::getFreqFromBandId(const int _i)
+{
+
+    if (freqBandIdHash.contains(_i))
+    {
+        return freqBandIdHash.value(_i);
+    }
+    else
+    {
+        return -1.0;
+    }
+    return -2.0;
+
+
+}
+
 bool DataBase::updateToLatest()
 {
 /*
@@ -1156,8 +1235,8 @@ bool DataBase::updateToLatest()
  * The updateXXX are recursive calls that calls the previous one.
  *
  */
-    //qDebug() << "DataBase::updateToLatest-003 " << endl;
-    return updateTo004();
+    //qDebug() << "DataBase::updateToLatest-005 " << endl;
+    return updateTo005();
 }
 
 bool DataBase::updateTo003()
@@ -1262,3 +1341,383 @@ bool DataBase::updateTo004()
     }
     return IAmIn004;
 }
+
+
+bool DataBase::updateTo005()
+{// Updates the DB to 0.0.5
+    /*
+     * This function should be used as a template to create the all the update functions implementing the needed changes
+     * in the dB to update from one version to the following one.
+     *
+     * // dbVersion shows the DB version that is being deployed
+     * // latestReaded shows the DB version that is currently deployed.
+     *i.e.:
+     *  QString stringQuery = QString ("ALTER TABLE award_enumeration ADD COLUMN dxcc INTEGER;");
+     *
+     */
+
+       //qDebug() << "DataBase::updateTo005" << endl;
+       bool IAmIn005 = false;
+       bool IAmIn004 = false;
+       bool ErrorUpdating = false;
+       QString stringQuery = QString();
+       QString dateString = (date.currentDateTime()).toString("yyyyMMdd");
+       QSqlQuery query;
+       QMessageBox msgBox;
+       msgBox.setIcon(QMessageBox::Information);
+       int errorCode;
+
+       bool sqlOk = false;
+
+       if (latestReaded >= 0.005)
+       {
+           //qDebug() << "DataBase::updateTo005 - Already in 005" << endl;
+           return true;
+       }
+       else
+       {
+           //qDebug() << "DataBase::updateTo005 - 005 update false" << endl;
+           IAmIn005 = false;
+       }
+
+
+       while (!IAmIn005 && !ErrorUpdating)
+       {
+           while (!IAmIn004 && !ErrorUpdating)
+           {               
+               IAmIn004 = updateTo004();
+           }
+           if (ErrorUpdating)
+           {
+               //qDebug() << "DataBase::updateTo005 - 005 update false2" << endl;
+               return false;
+           }
+           sqlOk = query.exec("INSERT INTO softwarecontrol (dateupgrade, softversion, dbversion) VALUES ('" + dateString + "', '" + softVersion + "', '" + QString::number(dbVersion) + "')");
+           if (sqlOk)
+           { // Version updated
+               if (recreateContestData())
+               {
+                   //qDebug() << "DataBase::updateTo005 - recreateContestData OK" << endl;
+                   sqlOk = query.exec ("DROP table logs");
+                   sqlOk = createTableLogs();
+                   if (!sqlOk)
+                   {
+                       //qDebug() << "DataBase::updateTo005 - logs table do not created" << endl;
+                   }
+
+
+                   if (howManyQSOsInLog(0)>0)
+                   { // If the user has QSOs that were added with previous versions...
+                     // We need to create a new log and rename all QSOs to that QSO.
+                     //stringQuery = QString("UPDATE log SET lognumber='1' WHERE lognumber='0'");
+
+
+                       msgBox.setText(QObject::tr("KLog has detected a previous log in the DB. All data will be migrated to a newly created DX type log for you."));
+                       msgBox.exec();
+
+                        if (query.exec("UPDATE log SET lognumber='1' WHERE lognumber='0'"))
+                        {}
+                        else
+                        {
+                            //showError(QObject::tr("QSOs not updated to main log"));
+                            //qDebug() << "DataBase::updateTo005 - QSOs not updated to main log" << endl;
+                            errorCode = query.lastError().number();
+                            //qDebug() << "DataBase::updateTo005 - query error: " << QString::number(errorCode) << endl;
+                            //qDebug() << "DataBase::updateTo005: LastQuery: " << query.lastQuery()  << endl;
+                            //qDebug() << "DataBase::updateTo005: LastError-data: " << query.lastError().databaseText()  << endl;
+                            //qDebug() << "DataBase::updateTo005: LastError-driver: " << query.lastError().driverText()  << endl;
+                            //qDebug() << "DataBase::updateTo005: LastError-n: " << QString::number(query.lastError().number() ) << endl;
+                        }
+
+                        QString dateString = (QDate::currentDate()).toString("yyyy/MM/dd");
+                        QString callToUse = QString();
+                        bool ok;
+                        //QString text;
+
+                        //text = QInputDialog::getText(this, QObject::tr("Station Callsign"), QObject::tr("Enter the Station Callsign you want to use in the imported log:"), QLineEdit::Normal, QObject::tr("N0CALL"), &ok);
+                        QString text = (QInputDialog::getText(0, QObject::tr("KLog: Enter Station callsign"),
+                                                                  QObject::tr("Enter the station callsign used in this log"), QLineEdit::Normal,
+                                                              QObject::tr("Station Callsign"), &ok)).toUpper();
+                        text.toUpper();
+                            if (ok && !text.isEmpty())
+                            {
+                                callToUse = text;
+                            }
+                            else
+                            {
+                                callToUse = "N0CALL";
+                            }
+
+//QString QInputDialog::getText ( QWidget * parent, const QString & title, const QString & label, QLineEdit::EchoMode mode = QLineEdit::Normal, const QString & text = QString(), bool * ok = 0, Qt::WindowFlags flags = 0, Qt::InputMethodHints inputMethodHints = Qt::ImhNone )
+
+
+                        stringQuery = QString("INSERT INTO logs (logdate, stationcall, logtype, logtypen) values('%1','%2','DX', '0')").arg(dateString).arg(callToUse);
+                        if (query.exec(stringQuery))
+                        {
+
+                        }
+                        else
+                        {
+                            //showError(QObject::tr("New Log not created"));
+                            //qDebug() << "DataBase::updateTo005 - New Log not created" << endl;
+                            //qDebug() << "DataProxy_SQLite::clearLog: Log deleted FAILED" << endl;
+                            errorCode = query.lastError().number();
+                            //qDebug() << "DataBase::updateTo005a - query error: " << QString::number(errorCode) << endl;
+                            //qDebug() << "DataBase::updateTo005a: LastQuery: " << query.lastQuery()  << endl;
+                            //qDebug() << "DataBase::updateTo005a: LastError-data: " << query.lastError().databaseText()  << endl;
+                            //qDebug() << "DataBase::updateTo005a: LastError-driver: " << query.lastError().driverText()  << endl;
+                            //qDebug() << "DataBase::updateTo005a: LastError-n: " << QString::number(query.lastError().number() ) << endl;
+
+                        }
+                   }
+                   else
+                   {
+
+                   }
+
+                   IAmIn005 = true;
+               }
+               else
+               {
+                   //qDebug() << "DataBase::updateTo005 - recreateContestData FAILED" << endl;
+                   ErrorUpdating = true;
+               }
+           }
+           else
+           { // Version not updated
+               //qDebug() << "DataBase::updateTo005 - 005 update false6" << endl;
+                ErrorUpdating = true;
+           }
+       }
+       //qDebug() << "DataBase::updateTo005 - 005 updated 3" << endl;
+
+       //TODO: Delete the table and recreate it
+       if (IAmIn005)
+       {
+            msgBox.setText(QObject::tr("All the data was migrated correctly. You should now to go to Setup->Preferences->Logs to check that everything is OK."));
+            msgBox.exec();
+       }
+       return IAmIn005;
+
+}
+bool DataBase::recreateContestData()
+{
+    QSqlQuery query;
+    bool sqlOk = false;
+    sqlOk = query.exec("DROP TABLE contest");
+    if (sqlOk)
+    {
+        if (createTableContest())
+        {
+            return populateContestData();
+        }
+    }
+    return false;
+
+}
+
+bool DataBase::updateLog()
+{
+    //qDebug() << "DataBase::updateLog"  << endl;
+    QSqlQuery query;
+    bool sqlOk = false;
+
+
+}
+
+bool DataBase::createTableLogs()
+{
+    QSqlQuery query;
+    return query.exec("CREATE TABLE logs ("
+               "id INTEGER PRIMARY KEY AUTOINCREMENT, "
+               "logdate VARCHAR(10), "
+               "stationcall VARCHAR(15) NOT NULL, "
+               "comment VARCHAR, "
+               "logtype VARCHAR, "
+               "logtypen INTEGER, "
+               "FOREIGN KEY (logtypen) REFERENCES supportedcontests(id),"
+               "FOREIGN KEY (logtype) REFERENCES supportedcontests(name))");
+}
+
+bool DataBase::createTableContest()
+{
+    QSqlQuery query;
+
+    query.exec("CREATE TABLE contest ("
+               "id INTEGER PRIMARY KEY AUTOINCREMENT, "
+               "contest INTEGER NOT NULL,"
+               "catoperator INTEGER NOT NULL,"
+               "catassisted INTEGER NOT NULL,"
+               "catpower INTEGER NOT NULL,"
+               "catband INTEGER NOT NULL,"
+               "catoverlay INTEGER NOT NULL,"
+               "catmode INTEGER NOT NULL,"
+               "FOREIGN KEY (contest) REFERENCES supportedcontests(id), "
+               "FOREIGN KEY (catoperator) REFERENCES contestcatoperator(id), "
+               "FOREIGN KEY (catassisted) REFERENCES contestcatassisted(id), "
+               "FOREIGN KEY (catpower) REFERENCES contestcatpower(id), "
+               "FOREIGN KEY (catband) REFERENCES contestcatband(id), "
+               "FOREIGN KEY (catoverlay) REFERENCES contestcatoverlay(id), "
+               "FOREIGN KEY (catmode) REFERENCES contestcatmode(id))");
+
+    query.exec("CREATE TABLE supportedcontests ("
+                   "id INTEGER PRIMARY KEY, "
+                   "longname VARCHAR,"
+                   "name VARCHAR)");
+
+    query.exec("CREATE TABLE contestcatoperator ("
+                   "id INTEGER PRIMARY KEY, "
+                   "name VARCHAR)");
+    
+    query.exec("CREATE TABLE contestcatassisted ("
+                   "id INTEGER PRIMARY KEY, "
+                   "name VARCHAR)");
+    
+    query.exec("CREATE TABLE contestcatpower ("
+                   "id INTEGER PRIMARY KEY, "
+                   "name VARCHAR)");
+    
+    query.exec("CREATE TABLE contestcatband ("
+                   "id INTEGER PRIMARY KEY, "
+                   "name VARCHAR)");
+    
+    query.exec("CREATE TABLE contestcatoverlay ("
+                   "id INTEGER PRIMARY KEY, "
+                   "name VARCHAR)");
+    
+    query.exec("CREATE TABLE contestcatmode ("
+                   "id INTEGER PRIMARY KEY, "
+                   "name VARCHAR)");
+
+    // ADDING ALL THE CATEGORIES OPTIONS
+
+    query.exec("INSERT INTO supportedcontests (id, longname, name) VALUES ('0', 'Normal log', 'DX')");
+
+   // query.exec("INSERT INTO supportedcontests (id, longname, name) VALUES ('1', 'CQ WW DX Contest(SSB)', 'CQ-WW-SSB')");
+
+    query.exec("INSERT INTO contestcatoperator (id, name) VALUES ('0', 'N/A')");
+    query.exec("INSERT INTO contestcatoperator (id, name) VALUES ('1', 'Single-Operator')");
+    query.exec("INSERT INTO contestcatoperator (id, name) VALUES ('2', 'Multi-One')");
+    query.exec("INSERT INTO contestcatoperator (id, name) VALUES ('3', 'Multi-Two')");
+    query.exec("INSERT INTO contestcatoperator (id, name) VALUES ('4', 'Multi-Unlimited')");
+    query.exec("INSERT INTO contestcatoperator (id, name) VALUES ('5', 'CheckLog')");
+
+    query.exec("INSERT INTO contestcatassisted (id, name) VALUES ('0', 'N/A')");
+    query.exec("INSERT INTO contestcatassisted (id, name) VALUES ('1', 'Non-Assisted')");
+    query.exec("INSERT INTO contestcatassisted (id, name) VALUES ('2', 'Assisted')");
+
+    query.exec("INSERT INTO contestcatpower (id, name) VALUES ('0', 'N/A')");
+    query.exec("INSERT INTO contestcatpower (id, name) VALUES ('1', 'High-Power')");
+    query.exec("INSERT INTO contestcatpower (id, name) VALUES ('2', 'Low-Power')");
+    query.exec("INSERT INTO contestcatpower (id, name) VALUES ('3', 'QRP')");
+
+    query.exec("INSERT INTO contestcatband (id, name) VALUES ('0', 'N/A')");
+    query.exec("INSERT INTO contestcatband (id, name) VALUES ('1', 'All-Band')");
+    query.exec("INSERT INTO contestcatband (id, name) VALUES ('2', 'Single-Band')");
+
+    query.exec("INSERT INTO contestcatoverlay (id, name) VALUES ('0', 'N/A')");
+    query.exec("INSERT INTO contestcatoverlay (id, name) VALUES ('1', 'Classic')");
+    query.exec("INSERT INTO contestcatoverlay (id, name) VALUES ('2', 'Rookie')");
+
+    query.exec("INSERT INTO contestcatmode (id, name) VALUES ('0', 'N/A')");
+    query.exec("INSERT INTO contestcatmode (id, name) VALUES ('1', 'SSB')");
+    query.exec("INSERT INTO contestcatmode (id, name) VALUES ('2', 'CW')");
+    query.exec("INSERT INTO contestcatmode (id, name) VALUES ('3', 'MIXED')");
+
+    return true;
+
+}
+
+
+bool DataBase::populateContestData()
+{
+    QSqlQuery query;
+
+    
+    // CONTEST DEFINITIONS START HERE
+
+    // DX
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (0, 0, 0, 0, 0, 0, 0)");
+    // DX START
+/*
+    // CQ WW DX SSB START
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 1, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 1, 2, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 2, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 2, 2, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 3, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 3, 2, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 1, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 1, 2, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 2, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 2, 2, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 3, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 3, 2, 0, 1)");
+
+
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 1, 1, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 1, 2, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 2, 1, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 2, 2, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 3, 1, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 3, 2, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 1, 1, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 1, 2, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 2, 1, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 2, 2, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 3, 1, 1, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 3, 2, 1, 1)");
+
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 1, 1, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 1, 2, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 2, 1, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 2, 2, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 3, 1, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 1, 3, 2, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 1, 1, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 1, 2, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 2, 1, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 2, 2, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 3, 1, 2, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 1, 2, 3, 2, 2, 1)");
+
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 2, 0, 1, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 2, 0, 2, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 3, 0, 1, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 3, 0, 2, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 4, 0, 1, 1, 0, 1)");
+    query.exec("INSERT INTO contest (contest, catoperator, catassisted, catpower, catband, catoverlay, catmode) VALUES (1, 5, 0, 0, 0, 0, 1)");
+    // CQ WW DX SSB END
+*/
+
+
+    return true;
+}
+
+bool DataBase::howManyQSOsInLog(const int i)
+{
+
+    //qDebug() << "DataProxy_SQLite::haveAtLeastOneLog()" << endl;
+    QSqlQuery query;
+    QString sqlQueryString = QString("SELECT COUNT(id) from log WHERE lognumber='%1'").arg(i);
+
+    if (query.exec(sqlQueryString))
+    {
+        query.next();
+        if (query.isValid())
+        {
+            return (query.value(0)).toInt();
+        }
+        else
+        {
+            return -1;
+        }
+    }
+    else
+    {
+        return -1;
+    }
+}
+
+
+
