@@ -26,23 +26,26 @@
  *                                                                           *
  *****************************************************************************/
 
-
+#include <QObject>
 #include <QSqlDatabase>
 #include <QMessageBox>
 #include <QSqlQuery>
 #include <QtSql>
 #include <QString>
 #include <QDateTime>
+#include <QInputDialog>
 
 class QSqlRelationalTableModel;
 
-// Last db update 0.0.4
-// Previous db update 0.0.3
-const float DBVersionf = 0.004;
+// Last db update 0.0.5
+// Previous db update 0.0.4
+const float DBVersionf = 0.005;
 
 class DataBase
 {
+
 public:
+    DataBase();
     DataBase(const QString _softVersion, bool  inmemoryonly = false);
     ~DataBase();
     bool createConnection();
@@ -66,6 +69,9 @@ public:
     QString getModeNameFromID2(const int _i);
 
     int getBandIdFromFreq(const QString fr); //Freq should be in MHz
+    bool isThisFreqInBand(const QString b, const QString fr); //Freq should be in MHz
+
+    double getFreqFromBandId(const int _i);
 
     bool unMarkAllQSO();
     bool updateIfNeeded();
@@ -79,10 +85,21 @@ private:
     bool updateToLatest();
     bool updateTo003(); // Updates the DB to 0.0.3
     bool updateTo004();
+    bool updateTo005();
 
     bool createTheBandQuickReference();
     bool createTheModeQuickReference();
 
+    bool updateLog(); // Updates the log table
+    bool createTableLog(); //Creates log=0 or selectedlog=1
+    bool createTableLogs();
+
+    bool recreateContestData();
+    bool createTableContest();
+    bool populateContestData();
+    bool howManyQSOsInLog(const int i);
+    void showError(const QString _errorC);
+
     float dbVersion;    // The current version of the DB. May differ from latestReaded if we are updating the DB!
     QString softVersion;
     float latestReaded; // The latest version of DB readed in the DB itself
@@ -92,9 +109,12 @@ private:
     QHash<QString, int> modeIDHash;
     QHash<int, QString> IDBandHash;
     QHash<int, QString> IDModeHash;
+    QHash<int, double> freqBandIdHash;
+
     QMap<QString, int> bandQMap;
     QMap<QString, int> modeQMap;
 
+
     //QSqlDatabase *db;
 
 };
