@@ -40,6 +40,7 @@ DataProxy::~DataProxy()
 
 void DataProxy::createLogModel(){}
 void DataProxy::createLogPanel(){}
+bool DataProxy::haveAtLeastOneLog(){return true;}
 
 int DataProxy::getIdFromModeName(const QString& _modeName)
 {
@@ -61,6 +62,10 @@ QString DataProxy::getNameFromModeId (const int _id)
     return "";
 }
 
+double DataProxy::getFreqFromBandId(const int _id)
+{
+    return -1.0;
+}
 
 int DataProxy::getLastQSOid()
 {
@@ -170,6 +175,53 @@ void DataProxy::compressDB()
 
 }
 
+int DataProxy::getDXCConYear(const int _year, const int _logNumber)
+{
+    return -1;
+}
+int DataProxy::getCQzonYear(const int _year, const int _logNumber)
+{
+    return -1;
+}
 
+QStringList DataProxy::getContestNames()
+{
+    return QStringList();
+}
 
+QStringList DataProxy::getContestCat(const int _catn){
+    return QStringList();
+}
 
+QStringList DataProxy::getContestOverlays()
+{
+    return QStringList();
+}
+
+QStringList DataProxy::getBandNames(){
+    return QStringList();
+}
+
+QStringList DataProxy::getValidCatOptions(const int _currentCat, const int _lowerCa)
+{
+    return QStringList();
+}
+
+int DataProxy::getNumberOfManagedLogs()
+{
+    return -1;
+}
+
+QString DataProxy::getStationCallSignFromLog(const int _log)
+{
+    return QString();
+}
+
+int DataProxy::getContestTypeN(const int _co, const int _catop, const int _catas, const int _catpo, const int _catba, const int _catov, const int _catmo)
+{
+    return -1;
+}
+QStringList DataProxy::getDataFromContestType(const int _n)
+{
+    return QStringList();
+}
