@@ -12,6 +12,7 @@ public:
     ~DataProxy();
     virtual void createLogModel();
     virtual void createLogPanel();
+    virtual bool haveAtLeastOneLog();
 
 
     //UI functions
@@ -22,6 +23,8 @@ public:
     virtual QString getNameFromBandId (const int _id);
     virtual QString getNameFromModeId (const int _id);
 
+    virtual double getFreqFromBandId(const int _id);
+
     virtual int getLastQSOid();
     virtual bool clearLog();
 
@@ -48,12 +51,23 @@ public:
 
     virtual QStringList getOperatingYears(const int _currentLog);
     virtual void compressDB();
-/*
-    virtual bool addDXMarathonQSO(const int _year, const int _dxcc, const int _cqz, const int _power, const int _mode, const int qsoid, const int _currentLog);
-    virtual int getDXMarathonTotalScore(const int _year);
-    virtual int getDXMarathonCountries(const int _year);
-    virtual int getDXMarathonCQZones(const int _year);
-*/
+
+    virtual int getDXCConYear(const int _year, const int _logNumber);
+    virtual int getCQzonYear(const int _year, const int _logNumber);
+
+    virtual QStringList getContestNames();
+    virtual QStringList getContestCat(const int _catn);
+    virtual QStringList getContestOverlays();
+    virtual int getContestTypeN(const int _co, const int _catop, const int _catas, const int _catpo, const int _catba, const int _catov, const int _catmo);
+    virtual QStringList getDataFromContestType(const int _n);
+
+    virtual QStringList getBandNames();
+
+    virtual QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
+
+
+    virtual int getNumberOfManagedLogs();
+    virtual QString getStationCallSignFromLog(const int _log);
 
 /*
     virtual bool isMultiplier(const QStringList _qs);
