@@ -15,12 +15,16 @@ public:
 
     void createLogModel();
     void createLogPanel();
+    bool haveAtLeastOneLog();
+
     int getIdFromModeName(const QString& _modeName);
     int getIdFromBandName(const QString& _bandName);
 
     QString getNameFromBandId (const int _id);
     QString getNameFromModeId (const int _id);
 
+    double getFreqFromBandId(const int _id);
+
     int getLastQSOid();
 
     bool deleteQSO(const int _qsoId);
@@ -48,6 +52,22 @@ public:
 
     bool clearLog();
 
+    int getDXCConYear(const int _year, const int _logNumber);
+    int getCQzonYear(const int _year, const int _logNumber);
+
+    QStringList getContestNames();
+    QStringList getContestCat(const int _catn);
+    QStringList getContestOverlays();
+    int getContestTypeN(const int _co, const int _catop, const int _catas, const int _catpo, const int _catba, const int _catov, const int _catmo);
+    QStringList getDataFromContestType(const int _n);
+
+    QStringList getBandNames();
+    QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
+
+
+    int getNumberOfManagedLogs();
+    QString getStationCallSignFromLog(const int _log);
+
 private:
     bool dbCreated;
     DataBase *db;
