@@ -35,10 +35,11 @@ This class calls all the othet "Setup..." to manage the configuration
 SetupDialog::SetupDialog(const bool _firstTime)
 {
     //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+    nolog = true;
     configFileName = "klogrc";
     version = ".";
     pageRequested = 0;
-
+    dataProxy = new DataProxy_SQLite();
 
     firstTime = _firstTime;
     if (firstTime)
@@ -50,7 +51,7 @@ SetupDialog::SetupDialog(const bool _firstTime)
         //qDebug() << "SetupDialog::SetupDialog FIRST TIME = FALSE" << endl;
     }
 
-    int logsPageTabN=-1;
+    logsPageTabN=-1;
 
     locator = new Locator();
 
@@ -103,7 +104,7 @@ SetupDialog::SetupDialog(const bool _firstTime)
     {
         tabWidget->setCurrentIndex(logsPageTabN);
     }
-
+    nolog = !(haveAtleastOneLog());
 }
 
 
@@ -112,7 +113,7 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
 {
     //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     firstTime = _firstTime;
-
+    dataProxy = new DataProxy_SQLite();
     configFileName = _configFile;
     version = _softwareVersion;
     pageRequested = _page;
@@ -122,7 +123,6 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
 
     tabWidget = new QTabWidget;
 
-
     userDataPage = new SetupPageUserDataPage();
     bandsModesPage = new SetupPageBandsModes(this);
     dxClusterPage = new SetupPageDxCluster(this);
@@ -179,7 +179,7 @@ SetupDialog::~SetupDialog()
 
 void SetupDialog::setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-    //qDebug() << "SetupDialog::setData" << endl;
+   //qDebug() << "SetupDialog::setData: " << QString::number(_page) << endl;
     firstTime = _firstTime;
     if (firstTime)
     {
@@ -213,14 +213,27 @@ void SetupDialog::setPage(const int _page)
 {
     //qDebug() << "SetupDialog::setPage("<<QString::number(_page) << ")" << endl;
     pageRequested = _page;
+
+    if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
+    {
+        tabWidget->setCurrentIndex(pageRequested);
+    }
 }
 
 void SetupDialog::slotCancelButtonClicked()
 {
 
     //qDebug() << "SetupDialog::slotCancelButtonClicked" << endl;
-    if (firstTime)
+    if (firstTime || nolog)
     {
+        if (nolog)
+        {
+            QMessageBox msgBox;
+            msgBox.setIcon(QMessageBox::Information);
+            msgBox.setText(tr("You need to enter at least one log in the Log's tab."));
+            msgBox.exec();
+            return;
+        }
         emit exitSignal(2);
     }
 
@@ -295,6 +308,22 @@ void SetupDialog::slotOkButtonClicked()
 //qDebug() << "SetupDialog::slotOkButonClicked" << endl;
 
     if ((userDataPage->getStationQrz()).length() < 3){ // There are no valid calls with less than 3 Chars
+        QMessageBox msgBox;
+        msgBox.setIcon(QMessageBox::Information);
+        msgBox.setText(tr("You need to enter at least a valid QRZ."));
+        msgBox.exec();
+        return;
+    }
+
+    if (!haveAtleastOneLog())
+    {
+        //qDebug() << "SetupDialog::slotOkButonClicked - NO LOG!" << endl;
+
+        QMessageBox msgBox;
+        msgBox.setIcon(QMessageBox::Information);
+        msgBox.setText(tr("You have not selected the kind of log you want.\nYou will be redirected to the Log tab.\nPlease add and select the kind of log you want to use."));
+        msgBox.exec();
+        tabWidget->setCurrentIndex(logsPageTabN);
         return;
     }
 
@@ -441,6 +470,7 @@ void SetupDialog::slotOkButtonClicked()
         stream << "WorkedColor=" << colorsPage->getWorkedColor() << ";" <<  endl;
         stream << "ConfirmedColor=" << colorsPage->getConfirmedColor() << ";" <<  endl;
         stream << "DefaultColor=" << colorsPage->getDefaultColor() << ";" <<  endl;
+        stream << "SelectedLog=" << QString::number(logsPage->getSelectedLog()) << ";" <<  endl;
 
 
         file.close ();
@@ -648,6 +678,8 @@ bool SetupDialog::processConfigLine(const QString _line)
         colorsPage->setConfirmedColor(value);
     }else if(values.at(0)=="DEFAULTCOLOR"){
         colorsPage->setDefaultColor(value);
+    }else if(values.at(0)=="SELECTEDLOG"){
+        logsPage->setSelectedLog(value.toInt());
 
     }else{
         //qDebug() << "SetupDialog::processConfigLine: NONE: " << endl;
@@ -785,3 +817,8 @@ QString SetupDialog::checkAndFixASCIIinADIF(const QString _data)
 
     return newString;
 }
+
+bool SetupDialog::haveAtleastOneLog()
+{
+    return dataProxy->haveAtLeastOneLog();
+}
