@@ -37,6 +37,8 @@
 #include "setuppagelogs.h"
 #include "setuppageworldeditor.h"
 
+#include "dataproxy_sqlite.h"
+
 
 #include "locator.h"
 
@@ -84,12 +86,15 @@ private:
     bool isValidBand (const QString b);
     bool isValidMode (const QString b);
     QString checkAndFixASCIIinADIF(const QString _data);
+    bool haveAtleastOneLog();
 
     bool firstTime; // To know if we are calling it from the Start wizard or not
+    bool nolog; // If there is no log being managed
     QString dxClusterServerToUse;
     QStringList dxClusterServers;
 
     QTabWidget *tabWidget;
+    int logsPageTabN;
 
     QListWidget *contentsWidget;
     QStackedWidget *pagesWidget;
@@ -108,7 +113,7 @@ private:
 
     QStringList bands, modes;
     Locator *locator;
-
+    DataProxy *dataProxy;
 
 };
 
